@@ -434,6 +434,16 @@ class QueryKit:
     ) -> Subscription[data_classes.Embargo]:
         ...
 
+    @overload
+    async def subscribe(
+        self,
+        model: SubscriptionModelLiteral,
+        event: SubscriptionEventLiteral,
+        filters: Optional[SubscriptionFilters] = ...,
+    ) -> Subscription[Any]:
+        ...
+
+
     async def subscribe(
         self,
         model: SubscriptionModelLiteral,
@@ -901,7 +911,7 @@ class Result:
     me: data_classes.ApiKeyDetails
     treasures: List[data_classes.Treasure]
     colors: List[data_classes.Color]
-    game_info: List[data_classes.GameInfo]
+    game_info: data_classes.GameInfo
     nations: List[data_classes.Nation]
     alliances: List[data_classes.Alliance]
     tradeprices: List[data_classes.Tradeprice]
@@ -1447,7 +1457,7 @@ class Socket:
             self.kit.subscription_auth_url,
             data={"socket_id": self.socket_id, "channel_name": subscription.channel},
         ) as response:
-            if response.status == 403:
+            if response.status != 200:
                 raise errors.Unauthorized()
             data = await response.json()
             self.kit.check_response_for_errors(data)
